@@ -18,5 +18,5 @@
 
     isim<-testdiscrimin(nrepet, rank, X.lw, length(unique(fac)), fac, X, nrow(X), ncol(X))
     obs<-isim[1]
-    return(as.randtest(isim[-1],obs))
+    return(as.randtest(isim[-1],obs,call=match.call()))
 }
